summaryrefslogtreecommitdiff
path: root/lib/CodeGen/ELFWriter.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/CodeGen/ELFWriter.h')
-rw-r--r--lib/CodeGen/ELFWriter.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/CodeGen/ELFWriter.h b/lib/CodeGen/ELFWriter.h
index 1e438929c0..e44ab3f838 100644
--- a/lib/CodeGen/ELFWriter.h
+++ b/lib/CodeGen/ELFWriter.h
@@ -86,9 +86,9 @@ namespace llvm {
/// and other object file specific stuff
const TargetLoweringObjectFile &TLOF;
/// TAI - Target Asm Info, provide information about section names for
/// globals and other target specific stuff.
- const MCAsmInfo *TAI;
+ const MCAsmInfo *MAI;
//===------------------------------------------------------------------===//
// Properties inferred automatically from the target machine.
@@ -118,7 +118,7 @@ namespace llvm {
unsigned NumSections; // Always = SectionList.size()
/// SectionLookup - This is a mapping from section name to section number in
/// the SectionList. Used to quickly gather the Section Index from TAI names
std::map<std::string, ELFSection*> SectionLookup;
/// PendingGlobals - Globals not processed as symbols yet.
@@ -86,9 +86,9 @@ namespace llvm {
/// and other object file specific stuff
const TargetLoweringObjectFile &TLOF;
- /// TAI - Target Asm Info, provide information about section names for
+ /// MAI - Target Asm Info, provide information about section names for
/// globals and other target specific stuff.
@@ -118,7 +118,7 @@ namespace llvm {
unsigned NumSections; // Always = SectionList.size()
/// SectionLookup - This is a mapping from section name to section number in
- /// the SectionList. Used to quickly gather the Section Index from TAI names
+ /// the SectionList. Used to quickly gather the Section Index from MAI names
std::map<std::string, ELFSection*> SectionLookup;
/// PendingGlobals - Globals not processed as symbols yet.